# Lithium plating parameters

Some example parameters for lithium plating from the paper:

> O’Kane, S. E. J., Campbell, I. D., Marzook, M. W. J., Offer, G. J., & Marinescu, M. (2020) Physical origin of the differential voltage minimum associated with lithium plating in Li-ion batteries. Journal of The Electrochemical Society 167(3), 090540.

Note: this parameter set does not claim to be representative of the true parameter values. Instead these are parameter values that were used to fit plating models to observed experimental data in the referenced papers.
